==> awl-docs-0.63-1-any.pkg.tar.zst: usr/share/doc/awl/annotated_dup.js <==
var annotated_dup =
[
    [ "AuthPlugin", "classAuthPlugin.html", "classAuthPlugin" ],
    [ "AwlCache", "classAwlCache.html", "classAwlCache" ],
    [ "AwlDatabase", "classAwlDatabase.html", "classAwlDatabase" ],
    [ "AwlDBDialect", "classAwlDBDialect.html", "classAwlDBDialect" ],
    [ "AwlQuery", "classAwlQuery.html", "classAwlQuery" ],
    [ "AwlUpgrader", "classAwlUpgrader.html", "classAwlUpgrader" ],
    [ "Browser", "classBrowser.html", "classBrowser" ],
    [ "BrowserColumn", "classBrowserColumn.html", "classBrowserColumn" ],
    [ "DBRecord", "classDBRecord.html", "classDBRecord" ],
    [ "Editor", "classEditor.html", "classEditor" ],
    [ "EditorField", "classEditorField.html", "classEditorField" ],
    [ "EMail", "classEMail.html", "classEMail" ],
    [ "EntryField", "classEntryField.html", "classEntryField" ],
    [ "EntryForm", "classEntryForm.html", "classEntryForm" ],
    [ "iCalComponent", "classiCalComponent.html", "classiCalComponent" ],
    [ "iCalProp", "classiCalProp.html", "classiCalProp" ],
    [ "MenuOption", "classMenuOption.html", "classMenuOption" ],
    [ "MenuSet", "classMenuSet.html", "classMenuSet" ],
    [ "Multipart", "classMultipart.html", null ],
    [ "PgQuery", "classPgQuery.html", "classPgQuery" ],
    [ "Session", "classSession.html", "classSession" ],
    [ "SinglePart", "classSinglePart.html", null ],
    [ "User", "classUser.html", "classUser" ],
    [ "Validation", "classValidation.html", "classValidation" ],
    [ "vCalendar", "classvCalendar.html", "classvCalendar" ],
    [ "vComponent", "classvComponent.html", "classvComponent" ],
    [ "vObject", "classvObject.html", null ],
    [ "vProperty", "classvProperty.html", "classvProperty" ],
    [ "XMLDocument", "classXMLDocument.html", "classXMLDocument" ],
    [ "XMLElement", "classXMLElement.html", "classXMLElement" ]
];

==> awl-docs-0.64-1-any.pkg.tar.zst: usr/share/doc/awl/annotated_dup.js <==
var annotated_dup =
[
    [ "AuthPlugin", "classAuthPlugin.html", "classAuthPlugin" ],
    [ "AwlCache", "classAwlCache.html", "classAwlCache" ],
    [ "AwlDatabase", "classAwlDatabase.html", "classAwlDatabase" ],
    [ "AwlQuery", "classAwlQuery.html", "classAwlQuery" ],
    [ "AwlUpgrader", "classAwlUpgrader.html", "classAwlUpgrader" ],
    [ "Browser", "classBrowser.html", "classBrowser" ],
    [ "BrowserColumn", "classBrowserColumn.html", "classBrowserColumn" ],
    [ "DBRecord", "classDBRecord.html", "classDBRecord" ],
    [ "Editor", "classEditor.html", "classEditor" ],
    [ "EditorField", "classEditorField.html", "classEditorField" ],
    [ "EMail", "classEMail.html", "classEMail" ],
    [ "EntryField", "classEntryField.html", "classEntryField" ],
    [ "EntryForm", "classEntryForm.html", "classEntryForm" ],
    [ "iCalComponent", "classiCalComponent.html", "classiCalComponent" ],
    [ "iCalProp", "classiCalProp.html", "classiCalProp" ],
    [ "MenuOption", "classMenuOption.html", "classMenuOption" ],
    [ "MenuSet", "classMenuSet.html", null ],
    [ "Multipart", "classMultipart.html", null ],
    [ "Session", "classSession.html", "classSession" ],
    [ "SinglePart", "classSinglePart.html", null ],
    [ "User", "classUser.html", "classUser" ],
    [ "Validation", "classValidation.html", "classValidation" ],
    [ "vCalendar", "classvCalendar.html", "classvCalendar" ],
    [ "vComponent", "classvComponent.html", "classvComponent" ],
    [ "vObject", "classvObject.html", null ],
    [ "vProperty", "classvProperty.html", "classvProperty" ],
    [ "XMLDocument", "classXMLDocument.html", "classXMLDocument" ],
    [ "XMLElement", "classXMLElement.html", "classXMLElement" ]
];
